import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    useRefresh,
    AutocompleteInput,
    DeleteButton,
    Button,
} from 'react-admin';
import { Box, Typography, Card, Stack, LinearProgress } from '@mui/material';
import { styled } from '@mui/material/styles';
import EmptyData from "../../components/EmptyData";
import MyCreateButton from "../../components/MyCreateButton";
import MyExportButton from '../../components/MyExportButton';
import PageDrawer from "../../components/PageDrawer";
import MyField from "../../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';
import request from '@/utils/request';
import WarehouseStockCreate from "./WarehouseStockCreate";
import WarehouseStockInfo from "./WarehouseStockInfo";
import MatnrListAside from "./MatnrListAside";

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 220
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <NumberInput source="locId" label="table.field.locItem.locId" />,
    <TextInput source="locCode" label="table.field.locItem.locCode" />,
    <TextInput source="type" label="table.field.locItem.type" />,
    <NumberInput source="orderItemId" label="table.field.locItem.orderItemId" />,
    <NumberInput source="wkType" label="table.field.locItem.wkType" />,
    <NumberInput source="matnrId" label="table.field.locItem.matnrId" />,
    <TextInput source="maktx" label="table.field.locItem.maktx" />,
    <TextInput source="unit" label="table.field.locItem.unit" />,
    <NumberInput source="anfme" label="table.field.locItem.anfme" />,
    <NumberInput source="workQty" label="table.field.locItem.workQty" />,
    <TextInput source="batch" label="table.field.locItem.batch" />,
    <TextInput source="spec" label="table.field.locItem.spec" />,
    <TextInput source="model" label="table.field.locItem.model" />,
    <TextInput source="fieldsIndex" label="table.field.locItem.fieldsIndex" />,
    <TextInput label="common.field.memo" source="memo" />,
]

const WarehouseStockList = () => {
    const translate = useTranslate();
    const [createDialog, setCreateDialog] = useState(false);
    const [matnrCode, setMatnrCode] = useState('');
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: 0,
                }}
                resource="warehouse/stock"
                title={"common.button.detail"}
                empty={false}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <SelectColumnsButton preferenceKey='locItem' />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='locItem'
                    bulkActionButtons={false}
                    rowClick={false}
                    expand={false}
                    expandSingle={true}
                    omit={['id', 'createTime', 'locId', 'spec', 'model', 'locCode', 'orderId', 'orderItemId', 'matnrId', 'splrBatch', 'createBy', 'memo', 'fieldsIndex']}
                >
                    <NumberField source="id" />
                    <NumberField source="locId" label="table.field.warehouseStock.locId" />
                    <TextField source="locCode" label="table.field.warehouseStock.locCode" />
                    <NumberField source="orderId" label="table.field.warehouseStock.orderId" />
                    <NumberField source="orderItemId" label="table.field.warehouseStock.orderItemId" />
                    <NumberField source="matnrId" label="table.field.warehouseStock.matnrId" />
                    <TextField source="matnrCode" label="table.field.warehouseStock.matnrCode" />
                    <TextField source="maktx" label="table.field.warehouseStock.maktx" />
                    <NumberField source="anfme" label="table.field.warehouseStock.anfme" />
                    <NumberField source="workQty" label="table.field.warehouseStock.qty" />
                    <TextField source="spec" label="table.field.warehouseStock.spec" />
                    <TextField source="model" label="table.field.warehouseStock.model" />
                    {/* <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField> */}
                    {/* <ReferenceField source="splrId" label="table.field.warehouseStock.splrId" reference="companys">
                        <TextField source="name" filterToQuery={(val) => ({ name: val })} />
                    </ReferenceField>, */}
                    <TextField source="batch" label="table.field.warehouseStock.batch" />
                    <TextField source="unit" label="table.field.warehouseStock.unit" />
                    <TextField source="fieldsIndex" label="table.field.warehouseStock.fieldsIndex" />
                    <TextField source="updateBy$" label="common.field.updateBy" />
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <WrapperField cellClassName="opt" label="common.field.opt">
                        <StockInfoButton />
                        <HistoriesButton setCreateDialog={setCreateDialog} setMatnrCode={setMatnrCode} />
                    </WrapperField>
                </StyledDatagrid>
            </List>
            <WarehouseStockInfo
                open={createDialog}
                setOpen={setCreateDialog}
                record={matnrCode}
            />
        </Box>
    )
}

export default WarehouseStockList;

const HistoriesButton = ({ setCreateDialog , setMatnrCode}) => {
    const record = useRecordContext();
    const historyClick = (event) => {
        event.stopPropagation();
        setCreateDialog(true)
        setMatnrCode(record?.matnrCode)
    }
    return (
        <Button label="common.button.histories" onClick={historyClick}></Button>
    )
}

const StockInfoButton = () => {
    const stockClick = (event) => {
        event.stopPropagation();
    }

    return (
        <Button label="common.button.detail" onClick={stockClick}></Button>
    )
}

